@@ -83,7 +83,8 @@ public:
 		signal_data_type;
 
 	/** Creates a new basic_server object.
-	 * @param ipv6 Whether to use IPv6.
+	 * @param ipv6 Whether to use IPv6 when no ipv6 parameter is given
+	 * to reopen.
 	 */
 	basic_server(bool ipv6 = true);
 
@@ -93,10 +94,12 @@ public:
 	basic_server(unsigned int port, bool ipv6 = true);
 	virtual ~basic_server();
 
+	void reopen(unsigned int port) { reopen(port, use_ipv6); }
+
 	/** (re)opens the server socket on port <em>port</em>, if it has
 	 * been shut down before.
 	 */
-	virtual void reopen(unsigned int port);
+	virtual void reopen(unsigned int port, bool ipv6);
 
 	/** Shuts down the server socket. New connections will no longer be
 	 * accepted, but already established connections stay open.
@@ -237,22 +240,22 @@ protected:
 	
 private:
 	void shutdown_impl();
-	void reopen_impl(unsigned int port);
+	void reopen_impl(unsigned int port, bool use_ipv6);
 };
 
 typedef basic_server<selector> server;
 
 template<typename selector_type>
 basic_server<selector_type>::basic_server(bool ipv6)
- : use_ipv6(ipv6), id_counter(0)
+ : id_counter(0), use_ipv6(ipv6)
 {
 }
 
 template<typename selector_type>
 basic_server<selector_type>::basic_server(unsigned int port, bool ipv6)
- : use_ipv6(ipv6), id_counter(0)
+ : id_counter(0), use_ipv6(ipv6)
 {
-	reopen_impl(port);
+	reopen_impl(port, ipv6);
 }
 
 template<typename selector_type>
@@ -264,9 +267,9 @@ basic_server<selector_type>::~basic_server()
 }
 
 template<typename selector_type>
-void basic_server<selector_type>::reopen(unsigned int port)
+void basic_server<selector_type>::reopen(unsigned int port, bool ipv6)
 {
-	reopen_impl(port);
+	reopen_impl(port, ipv6);
 }
 
 template<typename selector_type>
@@ -387,16 +390,16 @@ void basic_server<selector_type>::remove_client(const user* user)
 	on_disconnect(*user);
 
 	// Store ID of client to remove
-	unsigned int user_id = user->get_id();
+	unsigned int user_id = user->is_logged_in() ? user->get_id() : 0;
 	// Remove user to prevent server from sending the packet to the
 	// user we are currently removing
 	basic_object<selector_type>::user_remove(user);
 
 	// Build packet for other clients
-	if(user->is_logged_in() )
+	if(user_id)
 	{
 		packet pack("net6_client_part");
-		pack << user->get_id();
+		pack << user_id;
 		send(pack);
 	}
 }
@@ -646,12 +649,12 @@ void basic_server<selector_type>::shutdown_impl()
 }
 
 template<typename selector_type>
-void basic_server<selector_type>::reopen_impl(unsigned int port)
+void basic_server<selector_type>::reopen_impl(unsigned int port, bool ipv6)
 {
 	selector_type& selector = basic_object<selector_type>::get_selector();
 
 	// Open IPv4 socket on local port
-	if(!use_ipv6)
+	if(!ipv6)
 	{
 		ipv4_address bind_addr(port);
 		serv_sock.reset(new tcp_server_socket(bind_addr) );
